@@ -353,11 +353,13 @@ class _T5Loader(ExtendedJavaWrapper):
         super(_T5Loader, self).__init__(
             "com.johnsnowlabs.nlp.annotators.seq2seq.T5Transformer.loadSavedModel", path, jspark)
 
+
 class _GPT2Loader(ExtendedJavaWrapper):
     def __init__(self, path, jspark):
         super(_GPT2Loader, self).__init__(
             "com.johnsnowlabs.nlp.annotators.seq2seq.GPT2Transformer.loadSavedModel", path, jspark)
 
+
 class _MarianLoader(ExtendedJavaWrapper):
     def __init__(self, path, jspark):
         super(_MarianLoader, self).__init__(
@@ -494,7 +496,8 @@ class _XlnetSequenceClassifierLoader(ExtendedJavaWrapper):
             jspark)
 
 
-class _GPT2Loader(ExtendedJavaWrapper):
+class _DeBERTaLoader(ExtendedJavaWrapper):
     def __init__(self, path, jspark):
-        super(_GPT2Loader, self).__init__(
-            "com.johnsnowlabs.nlp.annotators.seq2seq.GPT2Transformer.loadSavedModel", path, jspark)
+        super(_DeBERTaLoader, self).__init__(
+            "com.johnsnowlabs.nlp.embeddings.DeBertaEmbeddings.loadSavedModel", path,
+            jspark)
